#
# spec file for package blueman
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude ^typelib\\(AppIndicator3\\)
%if 0%{?is_opensuse}
%bcond_without caja
%bcond_without nautilus
%bcond_without nemo
%else
%bcond_with caja
%bcond_with nautilus
%bcond_with nemo
%endif
Name:           blueman
Version:        2.4.2
Release:        1.3
Summary:        GTK Bluetooth Manager
License:        GPL-3.0-only
Group:          System/GUI/GNOME
URL:            https://github.com/blueman-project/blueman
Source:         https://github.com/%{name}-project/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  adwaita-icon-theme
BuildRequires:  automake
BuildRequires:  dbus-1-python3-devel
BuildRequires:  fdupes
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool >= 0.35.0
BuildRequires:  iproute2
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(bluez) >= 5.48
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.27.2
BuildRequires:  pkgconfig(python3) >= 3.8
Requires:       bluez >= 5.48
Requires:       dbus-1-python3
Requires:       gdk-pixbuf-loader-rsvg
Requires:       obex-data-server
Requires:       polkit
Requires:       pulseaudio-utils
Requires:       python3-cairo
Requires:       python3-gobject-Gdk
Requires:       python3-notify2
Requires:       dbus(org.freedesktop.Notifications)
%glib2_gsettings_schema_requires

%description
Blueman provides means for controlling the BlueZ API and presenting
Bluetooth operations such as:

    * Connecting to 3G/EDGE/GPRS via dial-up
    * Connecting to/Creating bluetooth networks
    * Connecting to input devices
    * Connecting to audio devices
    * Sending/Receiving/Browsing files via OBEX
    * Pairing

using a graphical user interface.

%package -n thunar-sendto-%{name}
Summary:        A sendto integration for Thunar
Group:          System/GUI/XFCE
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n thunar-sendto-%{name}
This package add sendto integration for Thunar.

%if %{with caja}
%package -n caja-extension-sendto-%{name}
Summary:        A sendto integration for Caja
Group:          System/GUI/Other
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(caja-python)
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n caja-extension-sendto-%{name}
This package add sendto integration for Caja.

%files -n caja-extension-sendto-%{name}
%{_datadir}/caja-python/extensions/caja_blueman_sendto.py
%endif

%if %{with nautilus}
%package -n nautilus-extension-sendto-%{name}
Summary:        A sendto integration for Nautilus
Group:          System/GUI/GNOME
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(nautilus-python)
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n nautilus-extension-sendto-%{name}
This package add sendto integration for Nautilus.

%files -n nautilus-extension-sendto-%{name}
%{_datadir}/nautilus-python/extensions/nautilus_blueman_sendto.py
%endif

%if %{with nemo}
%package -n nemo-extension-sendto-%{name}
Summary:        A sendto integration for Nemo
Group:          System/GUI/Other
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(nemo-python)
Requires:       %{name} = %{version}-%{release}
Enhances:       nemo
BuildArch:      noarch

%description -n nemo-extension-sendto-%{name}
This package add sendto integration for Nemo.

%files -n nemo-extension-sendto-%{name}
%{_datadir}/nemo-python/extensions/nemo_blueman_sendto.py
%endif

%lang_package

%prep
%autosetup
sed -i '1s/python.*/python3/' apps/%{name}-*
echo -e 'NotShowIn=KDE;GNOME;Pantheon;' >> data/%{name}.desktop.in

%build
%configure \
    --disable-static \
    --enable-polkit \
    --disable-schemas-compile
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print
rm -r %{buildroot}%{_datadir}/doc/%{name}

%fdupes %{buildroot}%{python3_sitelib}
%fdupes %{buildroot}%{_datadir}/icons/hicolor

%find_lang %{name}

%suse_update_desktop_file -i %{name}-manager

# Move blueman.rules to docs and leave default security untouched boo#1124339
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/polkit-1/rules.d/blueman.rules %{buildroot}%{_docdir}/%{name}/blueman.rules
rm -rf %{buildroot}%{_datadir}/polkit-1/rules.d

# openSUSE rcFOO links
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcblueman-mechanism
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcblueman-applet

%pre
%service_add_pre blueman-mechanism.service

%post
%service_add_post blueman-mechanism.service

%preun
%service_del_preun blueman-mechanism.service

%postun
%service_del_postun blueman-mechanism.service

%files
%doc CHANGELOG.md FAQ README.md blueman.rules
%license COPYING
%{_sysconfdir}/xdg/autostart/%{name}.desktop
%{_bindir}/%{name}-*
%{_libexecdir}/%{name}-mechanism
%{_libexecdir}/%{name}-rfcomm-watcher
%{python3_sitelib}/%{name}
%{python3_sitearch}/*%{name}*
%{_datadir}/applications/%{name}-manager.desktop
%{_datadir}/applications/%{name}-adapters.desktop
%{_datadir}/%{name}
%{_datadir}/dbus-1/system-services/org.%{name}.Mechanism.service
%{_datadir}/dbus-1/services/org.%{name}.Applet.service
%{_datadir}/dbus-1/services/org.%{name}.Manager.service
%{_datadir}/dbus-1/system.d/org.%{name}.Mechanism.conf
%{_datadir}/glib-2.0/schemas/org.%{name}.gschema.xml
%{_datadir}/icons/hicolor/*/*/blue*.*
%{_mandir}/man*/%{name}-*%{ext_man}
%{_datadir}/polkit-1/actions/org.%{name}.policy
%{_unitdir}/%{name}-mechanism.service
%{_userunitdir}/%{name}-applet.service
%{_userunitdir}/%{name}-manager.service
%{_sbindir}/rcblueman-mechanism
%{_sbindir}/rcblueman-applet

%files -n thunar-sendto-%{name}
%dir %{_datadir}/Thunar
%dir %{_datadir}/Thunar/sendto
%{_datadir}/Thunar/sendto/thunar-sendto-%{name}.desktop

%files lang -f %{name}.lang

%changelog
* Thu Jul 18 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.4.2:
  * Broken audio profile applet menu items
  * Missing manager window title
  * Teardown of DBus mock server in tests
  * Only a single battery notification
  * Renamed recent connections header in applet menu
  * Translation updates
  * An option to toggle the manager window with the tray icon (the 2.3 behavior
    useful when there are no window decorations for closing it)
- Update to version 2.4.1:
  * Fallback for missing icons
  * Correct Bluetooth state tracking in manager window
  * Sporadic error on battery data (Note that there was a regression
    in Linux 6.8.2, 6.7.11 and 6.6.23 that causes it and lots of other trouble)
  * Active state on tray icon
  * Broken markup in tray menu
  * Translation updates
  * Handle incompabilities with kded6 running on desktops without
    StatusNotifierItem support
- Update to version 2.4:
  * Fix device-selected handlers
  * Fix deprecations in tests
  * Fix showing -1 seconds when discovering @kuraga
  * Tray: Let dbus call end and reply to caller
  * Get the image-missing icon if lookup failed to avoid crash
  * Raise minimum Python version to 3.8
  * Raise minumum Gtk+ version to 3.24
  * Hide recent connections associated with unavailable adapters
  * Store network configuration in GSettings instead of
    /var/lib/blueman/network.state.
  * Replace custom MessageArea widget with regular Gtk.InfoBar
  * Drop auto-power feature. BlueZ now has the AutoEnable setting for even
    better auto-powering.
  * Do not use pointless link quality value
  * Recent connections in toplevel applet menu
  * Never hide keyboard and combos, see #1954 for more info
  * Do not close blueman-manager from applet
  * Add Switch to blueman-manager to set bluetooth on/off
  * Remove broken check for bluetooth status
  * PluginDialog: Replace custom list with Gtk.ListBox
  * Ignore double-click for connect when unpowered
  * Drop homgeneous from statusbar
  * PulseAudioUtils: Use python enums in several places
  * Use operator convenience functions
  * Cleanup PluginDialog UI
  * Show HCI device in blueman-adapers tabs
  * Show different icon for the active audio profile @localevil
  * Make blueman-services a notebook
  * Use the TypedDict as constructor
  * Audio profile switcher in applet menu (@abhijeetviswa)
  * Set router address as DNS server instead of loopback addresses
  * Enable dnsmasq DNS service if possible and add DNS servers otherwise
  * Reconfigure DHCP service on local nameserver changes
  * Support for systemd-resolved for getting nameservers for NAP clients
  * List connected devices in status icon tooltip
  * Support for nautilus 43 and later
  * Copy bleutooth address to clipboard in devicelist
  * Add battery levels to status icon tooltip
* Fri Feb 10 2023 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 2.3.5:
  * Right click menu was pointing to the wrong list row
  * Double click to connect
- Changes from version 2.3.4:
  * Errors when connected to a device with the DisconnectItems plugin enabled
- Changes from version 2.3.3:
  * Issues with NM PANU connections of equally named devices
  * Submenus in KDE Plasma tray
  * Avoid using StatusNotifierItem and GtkStatusIcon icons in parallel
  * Do not re-use dbusmenu item identifiers; avoids issues at least with
    gnome-shell-extension-appindicator
- Changes from version 2.3.2:
  * StatusNotifierItem submenus did not work in lxqt-panel (@niknah)
  * StatusNotifierItem vanished on panel restarts
  * StatusNotifierItem compatibility issues with libdbusmenu used at least
    by xfce4-panel and Waybar
  * StatusNotifierItem showed the menu on left click in xfce4-panel
- Changes from version 2.3.1:
  * StatusNotifierItem sent an incomplete NewStatus signal.
  * Avoid statusbar resize when showing progressbar
- Changes from version 2.3.0:
  * Blocked emblem was not visible for scales other than 1
  * Audio profile switcher in applet menu (@abhijeetviswa)
  * Symbolic tray icon option (GSettings switch symbolic-status-icons in
    org.blueman.general)
  * Replace AppIndicator with DBus StatusNotifierItem
  * Use a GtkTreeModelFilter to show/hide unnamed devices
  * Replace sigint hack with GLib to catch it
  * Port meson from deprecated python3 module
  * Rework battery handling
  * Merge Battery applet plugin into ConnectionNotifier
  * Symbolic icons and small UI improvements
- Changes from version 2.2.5:
  * Fix network interface iteration on 32 bit systems
  * Manager: Fix cancel button in send-note dialog
  * Fix battery and signals bars
- Removed blueman-2.2.4-ayatana-appindicator.patch as Appindicator
  has been replaced with DBus StatusNotifierItem
- Dependencies.md file is no longer packaged
* Mon Apr 11 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend -lang package: the auto-generated -lang package
  already contains relevant supplements.
* Mon Apr 11 2022 Maurizio Galli <maurizio.galli@suse.com>
- Added iproute2 build dependency to satisfy ip requirement
* Tue Mar  8 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.2.4:
  * Dropped the PIN database.
  * Fix that blueman-mechanism accepted arbitrary file paths and
    returned the errors from trying to open them,
    see https://github.com/blueman-project/blueman/security/advisories/GHSA-3r9p-m5c8-8mw8
- Add blueman-2.2.4-ayatana-appindicator.patch: Support
  Ayatana AppIndicators.
- Require dbus(org.freedesktop.Notifications) instead of
  notification-daemon.
* Sun Nov 28 2021 Alexei Podvalsky <avvissu@yandex.by>
- Disable agent startup on Pantheon desktop
* Sat Nov 13 2021 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 2.2.3
  * Recent connections disabled after suspend and resume
  * Service authorization notifications did not respond
  * Passkeys did not get displayed
- Updates from version 2.2.2
  * Issues with power level bars
  * Error message in blueman-mechanism
* Wed Jun  2 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.2.1
  * New Desktop notifications on connect / disconnect
  * New notifications with battery level for connecting devices
  * Allow cancelling device connection attempts
  * Allow opening device menus via keyboard (Shift+F10 or menu key)
  * Add Ctrl+Q and Ctrl+W accelerators for closing blueman-manager
  * Stop discovery and retry connection for broken adapter drivers
  * Improved passkey handling
  * Auto-connect settings for supported services
  * Fix hide devices with no name
  * Fix disconnecting NMDevice
  * Fix DiscvManager plugin showed its icon unreliably
  * Drop blueman-report, and blueman-assistant
- Add subpackages for caja, nautilus, and nemo sendto extensions
* Tue Nov  3 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.1.4
  * Security Release for CVE-2020-15238 (bsc#1178196)
  * Force cython to use python language version 3
  * Do not use exitcode 1 when we expect to fail
  * Mark more strings translatable
  * Unstranslated strings
  * Fix searching (with Ctrl+F in manager device list) did not work
  * Default PIN lookup
  * Fix device removal handling
  * Only use LaunchContext when we have proper event time
* Sun Jul 12 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.1.3
  * Force cython to use python language version 3
  * Fix tooltip not updating when bluetooth is disabled
  * Fix dbus timeout in DhcClient
  * Call the right method when pulseaudio crashes
  * Handle os.remove failing
* Wed Feb  5 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.1.2
  * Signal bar updates with multiple adapters
  * Pairing with pincode
* Tue Jul  9 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.1.1
  * Using recent connections did not work
  * Swichting adapters did not work
  * Errors when removing a device
  * Error tracebacks from info dialog
* Mon Jun 10 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.1
  * Support for BlueZ 4 and Python 2.7 and 3.2 got dropped
  * dbus-python and libnotify aren't dependencies anymore
  * libnm is now used for interaction with NetworkManager (>= 1.0)
  * Compatibility with gnome-icon-theme, mate-icon-theme, adwaita-icon-theme, elementary-xfce, and Papirus
  * Information dialog on devices' services
  * Compose and send notes to devices
  * Default PIN code database
  * Support for the ip command
  * udhdpd support
  * Lots of improvements for blueman-sendto
  * Lots of bug fixes and smaller or invisible improvements
  * See CHANGELOG.md for a complete list of changes
- Several spec file cleanups and adaptations
* Mon Feb  4 2019 maurizio.galli@gmail.com
- update to version 2.0.8
  * Fix name resolution of unknown device classes
- changes in  2.0.7
  * This release fixes DUN support in blueman through NetworkManager
  and bluemans own implementation with pppd. It has been broken due
  to lack of hardware as DUN is usually not available on newer devices.
  * Added default polkit rules file that allows users in group wheel
  to perform administrative actions.
  * Support iproute2 and make it the default
  * Fix icon name in the device menu
  * Several commits backported from master for various RFCOMM
  and Serial related bugs.
  * Fix icon and caption in manager for LE devices
- moved new polkit rules in docs to keep default security untouched
  (boo#1124339)
* Mon Nov 19 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Enable appindicator support. Needed for the newer xfce4-status-notifier.
  No longer breaks system tray
* Fri Jul 27 2018 matthias.gerstner@suse.com
- update to version 2.0.6: This fixes the security of the polkit authorization
  checks in blueman (bsc#1083066). Previously any user with access to the
  D-Bus system bus could trigger certain network configuration logic in
  blueman without authentication.
* Thu Apr 26 2018 badshah400@gmail.com
- Switch adwaita-icon-theme for gnome-icon-theme in BuildRequires.
- Run sed to change env-based hashbangs to ones depending directly
  on the system python3 binary.
- Only run post(un) scripts for openSUSE < 1500; rpm file triggers
  takes care of these for newer versions.
* Sat Nov  4 2017 aavindraa@gmail.com
- update to version 2.0.5
  * Bugs fixed
    + PPPSupport: Correct binary name for ModemManager
    + PPPSupport: Exclude grep process from process list
    + GameControllerWakeLock: Check for Class property before using it
    + SerialManager: Properly check for None
    + NetConf: Treat UnicodeDecodeError as if there was no file
    + Notification: Also check if notification daemon supports body
    + Correct bold tag in portugese translation (thanks @andreyluiz)
    + Properly check for None in SerialManager
    + GameControllerWakeLock: Check for Class property first
    + Fix bugs in NetworkService ui
    + NetConf: fix writing PID file for dhcpd(3)
    + Notification: Make sure x and y hint are in screen geometry
- ran spec-cleaner
* Fri Apr 28 2017 jengelh@inai.de
- Ensure neutrality of description
* Thu Apr 27 2017 bosim@opensuse.org
- ran spec-cleaner
* Thu Apr 27 2017 meissner@suse.com
- removed rpmlintrc
* Wed Apr  6 2016 and.november@opensuse.org
- update to version 2.0.4
* Fri Jan  1 2016 and.november@opensuse.org
- update to version 2.0.3
* Thu Dec 17 2015 and.november@opensuse.org
- update to version 2.0.2
* Fri Oct  9 2015 and.november@opensuse.org
- update to version 2.0.1
* Sun Jun 14 2015 and.november@opensuse.org
- build with python3
